@@ -9,5 +9,7 @@ from jsw_bio.base.keyword import keyword
 from jsw_bio.ncbi.ncbi_download_accids import ncbi_download_accids
 from jsw_bio.ncbi.ncbi_fasta_text import ncbi_fasta_text
 from jsw_bio.ncbi.ncbi_gb_text import ncbi_gb_text
+from jsw_bio.ncbi.ncbi_search_ipg import NcbiSearchIpg
+from jsw_bio.ncbi.ncbi_search_protein import NcbiSearchProtein
 from jsw_bio.ncbi.ncbi_search_ids import ncbi_search_ids
 from jsw_bio.ncbi.ncbi_sid import ncbi_sid
